pub struct InplaceBox<T: ?Sized, const SIZE: usize> { /* private fields */ }Expand description
A container similar to Box, but without heap allocation.
It stores data inline within a fixed-size buffer.
Implementations
Sourceimpl<T: ?Sized, const SIZE: usize> InplaceBox<T, SIZE>
impl<T: ?Sized, const SIZE: usize> InplaceBox<T, SIZE>
Sourcepub fn new<'a, U: Sized + Unsize<T> + 'a>(value: U) -> Self
pub fn new<'a, U: Sized + Unsize<T> + 'a>(value: U) -> Self
Construct a new object in-place in this object.
The type of the value must be convertible to dyn T and its size and
alignment less than or equal to that of the InplaceBox space for
the object.
Type match, size and alignment are checked statically by the compiler.
Sourceimpl<T: ?Sized, const SIZE: usize> InplaceBox<T, SIZE>
impl<T: ?Sized, const SIZE: usize> InplaceBox<T, SIZE>
Sourcepub unsafe fn new_unchecked<'a, U: Sized + Unsize<T> + 'a>(value: U) -> Self
pub unsafe fn new_unchecked<'a, U: Sized + Unsize<T> + 'a>(value: U) -> Self
Construct a new object in-place in this object, without checking the size.
The type of the value must be convertible to dyn T.
This constructor is provided to allow constructing objects either in
InplaceBox of a certain size or on heap for larger sizes. Since
if conditions in the caller on the object size are not optimized
out in debug mode, the code wouldn’t compile when statically checking
the size. With unchecked version, it’s possible to have such
dynamically-switched generics.
Safety
The caller needs to ensure that the size of the type U is less than or
equal to the SIZE of the InplaceBox. Only the type match and
alignment is checked statically by the compiler.
Prefer to use the safe Self::new constructor which checks for the
size.